==> proc-machine-learning-2.2.7-sources.jar: org/neo4j/gds/ml/linkmodels/pipeline/LinkPredictionPipelineCreateProc.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.gds.ml.linkmodels.pipeline;

import org.neo4j.gds.BaseProc;
import org.neo4j.gds.core.StringIdentifierValidations;
import org.neo4j.gds.ml.pipeline.PipelineCatalog;
import org.neo4j.gds.ml.pipeline.linkPipeline.LinkPredictionTrainingPipeline;
import org.neo4j.procedure.Description;
import org.neo4j.procedure.Name;
import org.neo4j.procedure.Procedure;

import java.util.stream.Stream;

import static org.neo4j.procedure.Mode.READ;

@SuppressWarnings("immutables:subtype")
public class LinkPredictionPipelineCreateProc extends BaseProc {

    @Procedure(name = "gds.beta.pipeline.linkPrediction.create", mode = READ)
    @Description("Creates a link prediction pipeline in the pipeline catalog.")
    public Stream<PipelineInfoResult> create(@Name("pipelineName") String input) {
        var pipelineName = StringIdentifierValidations.validateNoWhiteCharacter(input, "pipelineName");

        LinkPredictionTrainingPipeline pipeline = new LinkPredictionTrainingPipeline();
        PipelineCatalog.set(username(), pipelineName, pipeline);

        return Stream.of(new PipelineInfoResult(pipelineName, pipeline));
    }

}

==> proc-machine-learning-2.12.0-sources.jar: org/neo4j/gds/ml/linkmodels/pipeline/LinkPredictionPipelineCreateProc.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.gds.ml.linkmodels.pipeline;

import org.neo4j.gds.procedures.GraphDataScienceProcedures;
import org.neo4j.gds.procedures.pipelines.PipelineInfoResult;
import org.neo4j.procedure.Context;
import org.neo4j.procedure.Description;
import org.neo4j.procedure.Name;
import org.neo4j.procedure.Procedure;

import java.util.stream.Stream;

import static org.neo4j.procedure.Mode.READ;

public class LinkPredictionPipelineCreateProc {
    @Context
    public GraphDataScienceProcedures facade;

    @Procedure(name = "gds.beta.pipeline.linkPrediction.create", mode = READ)
    @Description("Creates a link prediction pipeline in the pipeline catalog.")
    public Stream<PipelineInfoResult> create(@Name("pipelineName") String input) {
        return facade.pipelines().linkPrediction().createPipeline(input);
    }
}
